/*
Toradex AG

SysInfoLib.h
Header file for the free avilible SysInfo Lib

See also the free sample SysInfoLibDemo
*/

#ifndef _SYSINFOLIB_H_
#define _SYSINFOLIB_H_

#ifdef __cplusplus
extern "C" {
#endif


#define SIL_VER_MAJ     1
#define SIL_VER_MIN     1
#define SIL_BUILD       0


// Flash Type IDs
#define TYPE_NOR		0x01
#define TYPE_NAND		0x02

// BSP Version Structure 
typedef struct {
	DWORD ID;
	DWORD Maj;
	DWORD Min;
} BSPVER;

// HW Version Structure 
typedef struct {
	WORD VerMaj;
	WORD VerMin;
	DWORD Variant;
} HWCFG;

// User Data Structure (256 Bytes fix) (Advanced Lib only)
typedef union {
	BYTE	bUserData[256];
	WORD	wUserData[128];
	DWORD	dwUserData[64];
} USERCFG;

// Processor Info Structure
typedef struct _PROCESSOR_INFO {
    WORD    wVersion;
    WCHAR   szProcessCore[40];
    WORD    wCoreRevision;
    WCHAR   szProcessorName[40];
    WORD    wProcessorRevision;
    WCHAR   szCatalogNumber[100];
    WCHAR   szVendor[100];
    DWORD   dwInstructionSet;
    DWORD   dwClockSpeed;
} PROCESSOR_INFO;


BOOL  GetOSVersion(LPOSVERSIONINFO pOSInfo);
BOOL  GetImageInfo(BSPVER* pBspVer, SYSTEMTIME* pBspDate);
BOOL  GetBootloaderInfo(BSPVER* pBspVer, SYSTEMTIME* pBspDate);

BOOL  GetSystemSpeeds(DWORD* pCpuSpeed, DWORD* pRamSpeed, DWORD* pBusSpeed);

BOOL  GetProcessorInfo(PROCESSOR_INFO* pPI);

BOOL  GetBoardVersion(HWCFG* pHWVer);
BOOL  GetBoardSerial(DWORD* pSerial);

BOOL  GetMACAddress(BYTE* pMAC);
BOOL  SetMACAddress(BYTE* pMAC);

DWORD GetFlashSize(DWORD* pFlashType);
DWORD GetMemorySize();

// Set System Frequencies for PXA270
// See also Colibri Tweak -> System Clocks
DWORD SetFrequencyPXA270(DWORD l, DWORD n, BOOL turbo, BOOL turbo2, BOOL fastBus, BOOL altmem, BOOL sram2);

// Set System Frequencies for PXA3xx
// See also Colibri Tweak -> System Clocks
DWORD SetFrequencyPXA3xx(DWORD l, DWORD n, DWORD hsio, DWORD sram, DWORD staticMem);

// Set core voltage in [mV]
// Return core voltage [mV]
// See also Colibri Tweak -> System Clocks
DWORD SetCoreVoltage(DWORD core_voltage);


#ifdef __cplusplus
}
#endif

#endif //_SYSINFOLIB_H_

